pub struct FeatureDeconvolutionEngine<'lifespan, T: Clone + Default, C: FeatureLike<MZ, T> + Clone + Default, S: IsotopicPatternScorer, F: IsotopicFitFilter> { /* private fields */ }Implementations
Sourceimpl<'lifespan, T: Clone + Default, C: FeatureLike<MZ, T> + Clone + Default, S: IsotopicPatternScorer, F: IsotopicFitFilter> FeatureDeconvolutionEngine<'lifespan, T, C, S, F>
impl<'lifespan, T: Clone + Default, C: FeatureLike<MZ, T> + Clone + Default, S: IsotopicPatternScorer, F: IsotopicFitFilter> FeatureDeconvolutionEngine<'lifespan, T, C, S, F>
pub fn new<I: Into<IsotopicModelLike<'lifespan>>>( isotopic_params: FeatureSearchParams, isotopic_model: I, scorer: S, fit_filter: F, ) -> Self
Sourcepub fn populate_isotopic_model_cache(
&mut self,
min_mz: f64,
max_mz: f64,
min_charge: i32,
max_charge: i32,
)
pub fn populate_isotopic_model_cache( &mut self, min_mz: f64, max_mz: f64, min_charge: i32, max_charge: i32, )
Pre-calculcate and cache all isotopic patterns between min_mz and max_mz for
charge states between min_charge and max_charge.
If this method is not used, experimental peaks will be used to seed the isotopic pattern caches which may lead to slightly different solutions depending upon the order in which peak lists are processed.
See also
pub fn deconvolute_features( &mut self, features: FeatureMap<MZ, T, C>, error_tolerance: Tolerance, charge_range: ChargeRange, minimum_size: usize, maximum_time_gap: f64, minimum_intensity: f32, max_missed_peaks: usize, ) -> Result<FeatureMap<Mass, T, DeconvolvedSolutionFeature<T>>, DeconvolutionError>